@@ -1,9 +1,10 @@
-import logging
-
-from uagents.config import REGISTRATION_FEE
+from uagents.config import REGISTRATION_FEE, get_logger
 from uagents.network import get_ledger, get_faucet
 
 
+LOGGER = get_logger("setup")
+
+
 def fund_agent_if_low(agent_address: str):
     ledger = get_ledger()
     faucet = get_faucet()
@@ -12,6 +13,6 @@ def fund_agent_if_low(agent_address: str):
 
     if agent_balance < REGISTRATION_FEE:
         # Add tokens to agent's wallet
-        logging.info("Adding funds to agent...")
+        LOGGER.info("Adding funds to agent...")
         faucet.get_wealth(agent_address)
-        logging.info("Adding funds to agent...complete")
+        LOGGER.info("Adding funds to agent...complete")
